"use strict";
/**
 * This file contains the logic for launching a cmi5 course package (AU).
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.initCmi5 = void 0;
const lrs_1 = require("../xapi/lrs");
const statements_1 = require("./statements");
const initCmi5 = () => __awaiter(void 0, void 0, void 0, function* () {
    const urlParams = new URLSearchParams(window.location.search);
    const endpoint = urlParams.get("endpoint");
    const fetchUrl = urlParams.get("fetch");
    const actorJson = urlParams.get("actor");
    const actor = JSON.parse(actorJson || "{}"); // this needs to be JSON decoded
    const activityId = urlParams.get("activityId");
    const registration = urlParams.get("registration") || undefined;
    if (!endpoint || !fetchUrl || !activityId) {
        throw new Error("Invalid query parameters for cmi5 init");
    }
    const response = yield fetch(fetchUrl, {
        method: "POST",
        credentials: "include",
        mode: "cors",
    });
    const data = yield response.json();
    if (!data["auth-token"]) {
        throw new Error("No auth-token in fetch");
    }
    const auth = data["auth-token"];
    const lrs = new lrs_1.Lrs({
        endpoint: endpoint,
        auth: `Basic ${auth}`,
    });
    const config = {
        lrs,
        actor,
        activityId,
        registration,
        initTimeSeconds: Date.now() / 1000,
        isCmi5: true,
        automaticTermination: true
    };
    const previousStateResponse = yield lrs.retrieveActivityState(activityId, "LMS.LaunchData", config.actor, registration);
    config.launchData = yield previousStateResponse.json();
    yield lrs.sendStatement((0, statements_1.buildCmi5Statement)(config, "initialized"));
    window.addEventListener("beforeunload", () => __awaiter(void 0, void 0, void 0, function* () {
        if (config.automaticTermination) {
            yield (0, statements_1.sendTerminated)(config);
        }
    }));
    return config;
});
exports.initCmi5 = initCmi5;
//# sourceMappingURL=launch.js.map