"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sendTerminated = exports.sendFailed = exports.sendPassed = exports.sendCompleted = exports.getDuration = exports.buildCmi5Statement = void 0;
const ADL_VERBS_ROOT = "http://adlnet.gov/expapi/verbs/";
const containsObject = (arr, key, value) => {
    return arr.some((obj) => obj[key] === value);
};
const buildCmi5Statement = (config, verbSuffix, result) => {
    var _a, _b, _c, _d;
    const contextTemplate = (_a = config.launchData) === null || _a === void 0 ? void 0 : _a.contextTemplate;
    // use templated category value
    const category = [
        ...(((_b = contextTemplate === null || contextTemplate === void 0 ? void 0 : contextTemplate.contextActivities) === null || _b === void 0 ? void 0 : _b.category) || []),
    ];
    if (!containsObject(category, "id", "https://w3id.org/xapi/cmi5/context/categories/cmi5")) {
        category.push({
            id: "https://w3id.org/xapi/cmi5/context/categories/cmi5",
            objectType: "Activity",
        });
    }
    // use templated grouping value
    const grouping = [
        ...(((_c = contextTemplate === null || contextTemplate === void 0 ? void 0 : contextTemplate.contextActivities) === null || _c === void 0 ? void 0 : _c.grouping) || []),
    ];
    if (result &&
        (result.success !== undefined || result.completion !== undefined) &&
        !containsObject(grouping, "id", "https://w3id.org/xapi/cmi5/context/categories/moveon")) {
        category.push({
            id: "https://w3id.org/xapi/cmi5/context/categories/moveon",
            objectType: "Activity",
        });
    }
    // use templated contextActivities
    const contextActivities = Object.assign({}, ((contextTemplate === null || contextTemplate === void 0 ? void 0 : contextTemplate.contextActivities) || {}));
    // replace with updated category and grouping
    contextActivities.category = category;
    contextActivities.grouping = grouping;
    // use templated extensions
    const extensions = Object.assign({}, ((contextTemplate === null || contextTemplate === void 0 ? void 0 : contextTemplate.extensions) || {}));
    const masteryScore = (_d = config.launchData) === null || _d === void 0 ? void 0 : _d.masteryScore;
    if (masteryScore !== undefined &&
        (verbSuffix === "passed" || verbSuffix === "failed")) {
        extensions["https://w3id.org/xapi/cmi5/context/extensions/masteryscore"] =
            masteryScore;
    }
    // use templated context
    const context = Object.assign({}, contextTemplate);
    // replace updated registration, contextActivities, extensions
    context.registration = config.registration || undefined;
    context.contextActivities = contextActivities;
    context.extensions = extensions;
    const statement = {
        actor: config.actor,
        object: {
            id: config.activityId,
            objectType: "Activity",
        },
        context,
        verb: {
            id: ADL_VERBS_ROOT + verbSuffix,
            display: {
                "en-US": verbSuffix,
            },
        },
    };
    if (result) {
        statement.result = result;
    }
    return statement;
};
exports.buildCmi5Statement = buildCmi5Statement;
const sendStatement = (config, statement, keepalive = false) => {
    if (!config) {
        return Promise.reject({
            error: "No LRS configured in the URL.",
            xhr: null,
        });
    }
    return config.lrs.sendStatement(statement, keepalive);
};
const getDuration = (config) => {
    if (!config.initTimeSeconds) {
        return undefined;
    }
    const now = Date.now() / 1000;
    const init = config.initTimeSeconds;
    const diff = (now - init).toFixed(2);
    return "PT" + diff + "S";
};
exports.getDuration = getDuration;
const sendCompleted = (config) => {
    return sendStatement(config, (0, exports.buildCmi5Statement)(config, "completed", {
        completion: true,
        duration: (0, exports.getDuration)(config),
    }));
};
exports.sendCompleted = sendCompleted;
const sendPassed = (config, score) => {
    return sendStatement(config, (0, exports.buildCmi5Statement)(config, "passed", {
        score,
        success: true,
        duration: (0, exports.getDuration)(config),
    }));
};
exports.sendPassed = sendPassed;
const sendFailed = (config, score) => {
    return sendStatement(config, (0, exports.buildCmi5Statement)(config, "failed", {
        score,
        success: false,
        duration: (0, exports.getDuration)(config),
    }));
};
exports.sendFailed = sendFailed;
const sendTerminated = (config) => {
    return sendStatement(config, (0, exports.buildCmi5Statement)(config, "terminated", { duration: (0, exports.getDuration)(config) }), true // keep alive even after the window is closed
    );
};
exports.sendTerminated = sendTerminated;
//# sourceMappingURL=statements.js.map