"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sendAttachments = exports.buildStatement = exports.convertMediaToAttachment = void 0;
const OL_VERBS_ROOT = "https://xapi.openlearning.com/verbs/";
const SUPPORTING_MEDIA_ATTACHMENT = "http://id.tincanapi.com/attachment/supporting_media";
const convertMediaToAttachment = ({ contentType, fileUrl, display, description, }) => {
    if (typeof display === "string") {
        display = {
            "en-US": display,
        };
    }
    if (typeof description === "string") {
        description = {
            "en-US": description,
        };
    }
    return {
        contentType: contentType,
        usageType: SUPPORTING_MEDIA_ATTACHMENT,
        display: display,
        description: description,
        fileUrl: fileUrl,
    };
};
exports.convertMediaToAttachment = convertMediaToAttachment;
const buildStatement = (config, attachments, verb) => {
    return {
        actor: config.actor,
        object: {
            id: config.activityId,
            objectType: "Activity",
        },
        context: {
            registration: config.registration, // the registration sent by OpenLearning
        },
        verb: {
            id: OL_VERBS_ROOT + verb,
            display: {
                "en-US": verb,
            },
        },
        attachments: attachments,
    };
};
exports.buildStatement = buildStatement;
const sendAttachments = (config, supportingMedia, verb = "published", thumbnailUrl) => {
    if (!config) {
        return Promise.reject({
            error: "No LRS configured in the URL.",
            xhr: null,
        });
    }
    const attachments = supportingMedia.map(exports.convertMediaToAttachment);
    if (thumbnailUrl) {
        attachments.unshift({
            contentType: "image/png",
            usageType: "https://xapi.openlearning.com/attachment/thumbnail",
            fileUrl: thumbnailUrl,
            display: {
                "en-US": "Thumbnail Image",
            },
            description: {
                "en-US": "Thumbnail Image",
            },
        });
    }
    const lrs = config.lrs;
    const statement = (0, exports.buildStatement)(config, attachments, verb);
    return lrs.sendStatement(statement);
};
exports.sendAttachments = sendAttachments;
//# sourceMappingURL=attachments.js.map