"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.retrieveActivityState = exports.saveActivityState = void 0;
const saveActivityState = (config, stateId, state) => {
    if (!config) {
        return Promise.reject({
            error: "No LRS configured in the URL.",
            xhr: null,
        });
    }
    const lrs = config.lrs;
    return lrs
        .saveActivityState(config.activityId, stateId, config.actor, state, config.registration)
        .then((response) => response.status === 200);
};
exports.saveActivityState = saveActivityState;
const retrieveActivityState = (config, stateId, defaultValue) => {
    if (!config) {
        return Promise.reject({
            error: "No LRS configured in the URL.",
            xhr: null,
        });
    }
    const lrs = config.lrs;
    return lrs
        .retrieveActivityState(config.activityId, stateId, config.actor, config.registration)
        .then((response) => {
        if (defaultValue !== undefined && response.status === 404) {
            return Promise.resolve(defaultValue);
        }
        else if (response.status !== 200) {
            return Promise.reject(response);
        }
        else {
            return response.json();
        }
    });
};
exports.retrieveActivityState = retrieveActivityState;
//# sourceMappingURL=activityState.js.map