"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sendTinCanCompleted = exports.sendTinCanScored = void 0;
const ADL_VERBS_ROOT = "http://adlnet.gov/expapi/verbs/";
const OL_EXTENSIONS_ROOT = "https://xapi.openlearning.com/extensions/";
const buildScoredStatement = (config, verbName, score) => {
    const result = {};
    if (score) {
        result.score = score;
    }
    return {
        actor: config.actor,
        object: {
            id: config.activityId,
            objectType: "Activity",
        },
        context: {
            registration: config.registration, // the registration sent by OpenLearning
        },
        verb: {
            id: ADL_VERBS_ROOT + verbName,
            display: {
                "en-US": verbName,
            },
        },
        result,
    };
};
const buildCompletedStatement = (config, submission) => {
    const ol_extensions = {};
    if (submission) {
        ol_extensions[OL_EXTENSIONS_ROOT + "submission-data"] = submission;
    }
    return {
        actor: config.actor,
        object: {
            id: config.activityId,
            objectType: "Activity",
        },
        context: {
            registration: config.registration, // the registration sent by OpenLearning
        },
        verb: {
            id: ADL_VERBS_ROOT + "completed",
            display: {
                "de-DE": "beendete",
                "en-US": "completed",
                "fr-FR": "a terminé",
                "es-ES": "completó",
            },
        },
        result: {
            completion: true,
            extensions: ol_extensions,
        },
    };
};
const sendTinCanScored = (config, score) => {
    if (!config) {
        return Promise.reject({
            error: "No LRS configured in the URL.",
            xhr: null,
        });
    }
    if (config.isCmi5) {
        throw new Error("Incompatible statement with cmi5 profile");
    }
    const lrs = config.lrs;
    const statement = buildScoredStatement(config, "scored", score);
    return lrs.sendStatement(statement);
};
exports.sendTinCanScored = sendTinCanScored;
const sendTinCanCompleted = (config, submission) => {
    if (!config) {
        return Promise.reject({
            error: "No LRS configured in the URL.",
            xhr: null,
        });
    }
    if (config.isCmi5) {
        throw new Error("Incompatible statement with cmi5 profile");
    }
    const lrs = config.lrs;
    const statement = buildCompletedStatement(config, submission);
    return lrs.sendStatement(statement);
};
exports.sendTinCanCompleted = sendTinCanCompleted;
//# sourceMappingURL=statements.js.map