"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.saveCompletion = void 0;
const ADL_VERBS_ROOT = "http://adlnet.gov/expapi/verbs/";
const OL_EXTENSIONS_ROOT = "https://xapi.openlearning.com/extensions/";
const buildStatement = (config, submission) => {
    const ol_extensions = {};
    if (submission) {
        ol_extensions[OL_EXTENSIONS_ROOT + "submission-data"] = submission;
    }
    return {
        actor: config.actor,
        object: {
            id: config.activity_id,
            objectType: "Activity",
        },
        context: {
            registration: config.registration, // the registration sent by OpenLearning
        },
        verb: {
            id: ADL_VERBS_ROOT + "completed",
            display: {
                "de-DE": "beendete",
                "en-US": "completed",
                "fr-FR": "a terminé",
                "es-ES": "completó",
            },
        },
        result: {
            completion: true,
            extensions: ol_extensions,
        },
    };
};
const saveCompletion = (config, submission) => {
    if (!config) {
        return Promise.reject({
            error: "No LRS configured in the URL.",
            xhr: null,
        });
    }
    const lrs = config.lrs;
    const statement = buildStatement(config, submission);
    return lrs.saveStatement(statement);
};
exports.saveCompletion = saveCompletion;
//# sourceMappingURL=xapi-completion.js.map