"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.saveScored = exports.saveFailed = exports.savePassed = void 0;
const ADL_VERBS_ROOT = "http://adlnet.gov/expapi/verbs/";
const buildStatement = (config, verbName, score) => {
    const result = {};
    if (score) {
        result.score = score;
    }
    return {
        actor: config.actor,
        object: {
            id: config.activity_id,
            objectType: "Activity",
        },
        context: {
            registration: config.registration, // the registration sent by OpenLearning
        },
        verb: {
            id: ADL_VERBS_ROOT + verbName,
            display: {
                "en-US": verbName
            },
        },
        result
    };
};
const savePassed = (config, score) => {
    if (!config) {
        return Promise.reject({
            error: "No LRS configured in the URL.",
            xhr: null,
        });
    }
    const lrs = config.lrs;
    const statement = buildStatement(config, "passed", score);
    return lrs.saveStatement(statement);
};
exports.savePassed = savePassed;
const saveFailed = (config, score) => {
    if (!config) {
        return Promise.reject({
            error: "No LRS configured in the URL.",
            xhr: null,
        });
    }
    const lrs = config.lrs;
    const statement = buildStatement(config, "failed", score);
    return lrs.saveStatement(statement);
};
exports.saveFailed = saveFailed;
const saveScored = (config, score) => {
    if (!config) {
        return Promise.reject({
            error: "No LRS configured in the URL.",
            xhr: null,
        });
    }
    const lrs = config.lrs;
    const statement = buildStatement(config, "scored", score);
    return lrs.saveStatement(statement);
};
exports.saveScored = saveScored;
//# sourceMappingURL=xapi-score.js.map